@@ -170,7 +170,9 @@ def add_custom_commands():
             previous = rectangle
             i += 1
 
-        stitched_image = stitched_image.resize((int(stitched_image.width * 0.5), int(stitched_image.height * 0.5)))
+        if stitched_image.height > 14000:
+            qrf = 14000 / stitched_image.height
+            stitched_image = stitched_image.resize((int(stitched_image.width * qrf), int(stitched_image.height * qrf)))
         return stitched_image
 
     def __show_elements(selenium, elements):
@@ -188,7 +190,7 @@ def add_custom_commands():
         if elements is not None:
             try:
                 for element in elements:
-                    selenium.execute_script("arguments[0].setAttribute('style', 'opacity:1;');", element)
+                    selenium.execute_script("arguments[0].setAttribute('style', arguments[0].getAttribute('style')+'; opacity:1;');", element)
             except WebDriverException as error:
                 print('Error : ', str(error))
 
@@ -207,7 +209,7 @@ def add_custom_commands():
         if elements is not None:
             try:
                 for element in elements:
-                    selenium.execute_script("arguments[0].setAttribute('style', 'opacity:0;');", element)
+                    selenium.execute_script("arguments[0].setAttribute('style', arguments[0].getAttribute('style')+'; opacity:0;');", element)
             except WebDriverException as error:
                 print('Error : ', str(error))
 
